@@ -18,7 +18,7 @@ use Text::Abbrev();
 use Exporter ();
 our @ISA = qw{ Exporter };
 
-our $VERSION = '0.000_007';
+our $VERSION = '0.000_008';
 
 our @EXPORT_OK = qw{
     __date_to_day_of_year
@@ -122,6 +122,13 @@ use constant GREGORIAN_RATA_DIE_TO_SHIRE	=> 1995694;
 
 	if ( HASH_REF eq $ref ) {
 	    my %hash = %{ $date };
+	    if ( $hash{month} ) {
+		$hash{holiday} = 0;
+	    } else {
+		$hash{holiday}
+		    or $hash{holiday} = $hash{day};
+		$hash{day} = 0;
+	    }
 	    $date = bless \%hash, join '::', __PACKAGE__, 'Date';
 	}
 
@@ -133,6 +140,10 @@ use constant GREGORIAN_RATA_DIE_TO_SHIRE	=> 1995694;
 	    } or Carp::croak( FORMAT_DATE_ERROR );
 	}
 
+	my $ctx = {
+	    prefix_new_line_unless_empty	=> 0,
+	};
+
 	$tplt =~ s/ % (?: [{]  ( \w+ ) [}]	# method ($1)
 	    | [{]{2} ( .*? ) [}]{2}		# condition ($2)
 	    | ( [0-9]+ ) N			# %nnnN ($3)
@@ -140,7 +151,7 @@ use constant GREGORIAN_RATA_DIE_TO_SHIRE	=> 1995694;
 	) /
 	    $1 ? ( $date->can( $1 ) ? $date->$1() : "%{$1}" ) :
 	    $2 ? _fmt_cond( $date, $2 ) :
-	    $4 ? _fmt_conv( $date, $4 ) :
+	    $4 ? _fmt_conv( $date, $4, $ctx ) :
 	    _fmt_nano( $date, $3 )
 	/smxeg;
 
@@ -187,15 +198,13 @@ sub _fmt_get_md {
 	d	=> sub { sprintf '%02d', $_[0]->day() || $_[0]->holiday() },
 	EA	=> sub { __trad_weekday_name( $_[0]->day_of_week() ) },
 	Ea	=> sub { __trad_weekday_short( $_[0]->day_of_week() ) },
-	ED	=> sub {
-	    my $d = __on_date( _fmt_get_md( $_[0] ) );
-	    defined $d
-		and $d = "\n$d";
-	    return $d;
+	ED	=> sub { $_[1]{on_date_accented} = 1;
+	    goto &_fmt_on_date;
 	},
-	Ed	=> sub { __on_date( _fmt_get_md( $_[0] ) ) },
+	Ed	=> \&_fmt_on_date,
 	EE	=> sub { __holiday_name( $_[0]->holiday() || 0 ) },
 	Ee	=> sub { __holiday_short( $_[0]->holiday() || 0 ) },
+	En	=> sub { $_[1]{prefix_new_line_unless_empty}++; '' },
 	Ex	=> sub { __format( $_[0],
 		'%{{%A %e %B %Y||%A %EE %Y||%EE %Y}}' ) },
 	e	=> sub { sprintf '%2d', $_[0]->day() || $_[0]->holiday() },
@@ -242,12 +251,12 @@ sub _fmt_get_md {
     $spec{X} = $spec{r};	# I think this is right ...
 
     sub _fmt_conv {
-	my ( $date, $rslt ) = @_;
+	my ( $date, $rslt, $ctx ) = @_;
 	my $code;
 	if ( $code = $spec{$rslt} ) {
-	    $rslt = $code->( $date );
+	    $rslt = $code->( $date, $ctx );
 	} elsif ( 1 < length $rslt and $code = $spec{ substr $rslt, 1 } ) {
-	    $rslt = $code->( $date );
+	    $rslt = $code->( $date, $ctx );
 	}
 	return defined $rslt ? $rslt : '';
     }
@@ -269,6 +278,18 @@ sub _fmt_offset {
 	sprintf( '%s%02d%02d', $sign, $hr, $min );
 }
 
+sub _fmt_on_date {
+    my ( $date, $ctx ) = @_;
+    my @md = _fmt_get_md( $date );
+    my $pfx = "\n" x $ctx->{prefix_new_line_unless_empty};
+    $ctx->{prefix_new_line_unless_empty} = 0;
+    defined( my $on_date = delete $ctx->{on_date_accented} ?
+	__on_date_accented( @md ) :
+	__on_date( @md )
+    ) or return undef;	## no critic (ProhibitExplicitReturnUndef)
+    return "$pfx$on_date";
+}
+
 sub _fmt_nano {
     my ( $date, $places ) = @_;
     $places ||= 9;
@@ -559,7 +580,6 @@ sub __is_leap_year {
     }
 }
 
-# TODO In a leap year, day 366 is assigned to the wrong year.
 sub __rata_die_to_year_day {
     my ( $rata_die ) = @_;
 
@@ -801,6 +821,14 @@ methods). The methods (or keys) used are:
 The first seven are heavily used. The last four are used only by
 C<'%N'>, C<'%s'>, C<'%z'>, and C<'%Z'> respectively.
 
+If you pass a hash, the canonical say specification is either a
+non-zero C<month> and C<day> and zero C<holiday>, or vice versa. But if
+you pass a zero C<month> and C<holiday>, the method will assume that you
+were specifying a holiday and adjust the hash accordingly, though this
+adjustment will not be visible outside C<__format()>. Also, your hash
+need not specify C<day_of_week> since it can be computed from C<month>
+and C<day>, or C<holiday>.
+
 The following conversion specifications (to use C<strftime()>
 terminology) or patterns (to use L<DateTime|DateTime> terminology) are
 supported. Note that these have been extended by the use of C<'%E*'>
@@ -870,14 +898,19 @@ part of no week.
 
 =item %ED
 
-The L<__on_date()|/__on_date> text for the given date, with a leading
-"\n" if there is in fact an event on that date. This makes '%Ex%n%ED'
-produce exactly the same text as L<__on_date()|/__on_date>.
+The L<__on_date_accented()|/__on_date_accented> text for the given date.
+
+You can get a leading C<"\n"> if there was an actual event using
+C<'%En%ED'>.
 
 =item %Ed
 
 The L<__on_date()|/__on_date> text for the given date.
 
+You can get a leading C<"\n"> if there was an actual event using
+C<'%En%Ed'>. So to mimic L<Date::Tolkien::Shire|Date::Tolkien::Shire>
+L<on_date()|Date::Tolkien::Shire/on_date>, use C<'%Ex%n%En%Ed'>.
+
 =item %EE
 
 The full holiday name, or C<''> for non-holidays.
@@ -886,6 +919,12 @@ The full holiday name, or C<''> for non-holidays.
 
 The abbreviated holiday name, or C<''> for non-holidays.
 
+=item %En
+
+Inserts nothing, but causes the next C<%Ed> or C<%ED> (and B<only> the
+next one) to have a C<"\n"> prefixed if there was an actual event on the
+date.
+
 =item %Ex
 
 Like C<'%c'>, but without the time of day, and with full names rather
